from instagrump.Profile import Profile
from instagrump.Content import Content

def content_test():
	return Content('https://www.instagram.com/p/B09HQvnHjV_/?utm_source=ig_web_copy_link')

def profile_test():
	return Profile('anyageraldine')